@@ -6,7 +6,7 @@
 */
 /* libburn wrappers for libisoburn 
 
-   Copyright 2007 - 2014  Thomas Schmitt, <scdbackup@gmx.net> 
+   Copyright 2007 - 2016  Thomas Schmitt, <scdbackup@gmx.net> 
    Provided under GPL version 2 or later.
 */
 
@@ -77,7 +77,7 @@ int isoburn_initialize(char msg[1024], int flag)
 
 
 /* First the ugly compile time checks for header version compatibility.
-   If everthing matches, then they produce no C code. In case of mismatch,
+   If everything matches, then they produce no C code. In case of mismatch,
    intentionally faulty C code will be inserted.
 */
 
@@ -532,7 +532,7 @@ ex:
                 bit5= ignore ACL from external filesystems
                 bit6= ignore POSIX Extended Attributes from external filesystems
                 bit7= pretend -ROM profile and scan for table of content
-                bit8= re-assess (*drive_infos)[0] rather than aquiring adr
+                bit8= re-assess (*drive_infos)[0] rather than acquiring adr
                 bit9= when scanning for ISO 9660 sessions on overwritable
                       media: Do not demand a valid superblock at LBA 0
                       and scan until end of medium.
