@@ -3,7 +3,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2017 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -111,6 +111,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
    free(leafname);
    return(-1);
  }
+
+ /* Base initialization by actions which must not fail */
+
  m->libs_are_started= 0;
  strncpy(m->progname,progname,sizeof(m->progname)-1);
  m->progname[sizeof(m->progname)-1]= 0;
@@ -140,6 +143,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_fat= 0;
  m->do_rockridge= 1;
  m->do_iso1999= 0;
+ m->ecma119_map= 1;
  m->do_aaip= 0;
  m->do_md5= 0;
  m->no_emul_toc= 0;
@@ -157,6 +161,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_follow_param= 0;
  m->do_follow_links= 0;
  m->follow_link_limit= 100;
+ m->resolve_link_rec_count= 0;
+ m->resolve_link_rec_limit= 100;
+ m->do_follow_concat= 0;
  m->do_follow_mount= 1;
  m->do_global_uid= 0;
  m->global_uid= 0;
@@ -198,7 +205,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->image_start_value[0]= 0;
  m->displacement= 0;
  m->displacement_sign= 0;
+ m->read_fs= 0;
  m->drives_exclusive= 1;
+ m->linux_scsi_dev_family= 0;
  m->early_stdio_test= 0;
  m->cache_num_tiles= 0;
  m->cache_tile_blocks= 0;
@@ -227,14 +236,25 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->ban_stdio_write= 0;
  m->do_dummy= 0;
  m->do_close= 0;
- m->speed= 0;
+ m->auto_close= 0;
+ m->write_speed= 0;  /* max */
+ m->read_speed= -2;  /* do not set */
  m->fs= 4*512; /* 4 MiB */
  m->padding= 300*1024;
  m->do_padding_by_libisofs= 0;
  m->alignment= 0;
  m->do_stream_recording= 0;
  m->dvd_obs= 0;
+ m->modesty_on_drive= 0;
+ m->min_buffer_usec= 5000;
+ m->max_buffer_usec= 25000;
+ m->buffer_timeout_sec= 120;
+ m->min_buffer_percent= 90;
+ m->max_buffer_percent= 95;
+ m->use_immed_bit= 0;
+ m->use_immed_bit_default= 0;
  m->stdio_sync= 0;
+ m->stdio_sync_is_default= 1;
  m->keep_boot_image= 0;
  m->boot_image_cat_path[0]= 0;
  m->boot_image_cat_hidden= 0;
@@ -246,6 +266,8 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->boot_image_emul= 0;
  m->boot_emul_default= 1;
  m->boot_image_load_size= 4 * 512;     /* hearsay out of libisofs/demo/iso.c */
+ m->boot_img_size_default= 1;
+ m->boot_img_full_size= 0;
  memset(m->boot_id_string, 0, sizeof(m->boot_id_string));
  memset(m->boot_selection_crit, 0, sizeof(m->boot_selection_crit));
 
@@ -257,6 +279,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
 
  m->boot_efi_default= 0;
  m->system_area_disk_path[0]= 0;
+ m->system_area_clear_loaded= 0;
  m->system_area_options= 0;
  m->patch_system_area= 0;
  m->partition_offset= 0;
@@ -268,6 +291,12 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
    m->appended_partitions[i]= NULL;
    m->appended_part_types[i]= 0;
  }
+ m->appended_as_gpt= 0;
+ m->appended_as_apm= 0;
+ m->part_like_isohybrid= 0;
+ m->iso_mbr_part_type= -1;
+ memset(m->gpt_guid, 0, 16);
+ m->gpt_guid_mode= 0;
  m->ascii_disc_label[0]= 0;
  m->grub2_sparc_core[0]= 0;
  memset(m->hfsp_serial_number, 0, 8);
@@ -278,6 +307,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->vol_expiration_time= 0;
  m->vol_effective_time= 0;
  m->vol_uuid[0]= 0;
+ m->all_file_dates[0]= 0;
 
 #ifdef Xorriso_with_libjtE
  m->libjte_handle= NULL;
@@ -304,6 +334,7 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
  m->do_disk_pattern= 2;
  m->temp_mem_limit= 16*1024*1024;
  m->file_size_limit= Xorriso_default_file_size_limiT;
+ m->file_name_limit= 255;
  m->disk_exclusions= NULL;
  m->iso_rr_hidings= NULL;
  m->joliet_hidings= NULL;
@@ -418,6 +449,10 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
 
  m->update_flags= 0;
 
+ m->show_hfs_cmd_flag= 0;
+ m->show_hfs_cmd_count= 0;
+ m->show_hfs_cmds= NULL;
+
  m->result_line[0]= 0;
  m->result_line_counter= 0;
  m->result_page_counter= 0;
@@ -425,6 +460,9 @@ int Xorriso_new(struct XorrisO ** xorriso,char *progname, int flag)
 
  m->info_text[0]= 0;
 
+
+ /* Here begin actions which might fail */
+
  ret= Sfile_leafname(progname, leafname, 0);
  if(ret<=0)
    goto failure;
@@ -539,6 +577,8 @@ int Xorriso_destroy(struct XorrisO **xorriso, int flag)
    free(m->in_charset);
  if(m->out_charset!=NULL)
    free(m->out_charset);
+ Checkmediajob_destroy(&(m->check_media_default), 0);
+ Sectorbitmap_destroy(&(m->in_sector_map), 0);
  Xorriso_destroy_re(m,0);
  Exclusions_destroy(&(m->disk_exclusions), 0);
  Exclusions_destroy(&(m->iso_rr_hidings), 0);
