@@ -372,6 +372,7 @@ int Xorriso_get_volid(struct XorrisO *xorriso, char volid[33], int flag)
  bit2= is_default
  bit3= append -boot_image any next
  bit4= concentrate boot options
+ bit5= override load_size by "full"
 */
 int Xorriso_boot_item_status(struct XorrisO *xorriso, char *cat_path,
                              char *bin_path, int platform_id,
@@ -389,6 +390,8 @@ int Xorriso_boot_item_status(struct XorrisO *xorriso, char *cat_path,
 
  no_defaults= flag & 1;
  line= xorriso->result_line;
+ if(flag & 32)
+   load_size= -1;
 
  if((flag & 16) && bin_path[0] != 0) {
    /* Concentrate boot options. */
@@ -422,11 +425,14 @@ int Xorriso_boot_item_status(struct XorrisO *xorriso, char *cat_path,
 
    file_size= 0;
    ret= Xorriso_iso_lstat(xorriso, bin_path, &stbuf, 2 | 4);
-   if(ret == 0)
+   if(ret == 0) {
      file_size= ((stbuf.st_size / (off_t) 512) +
                 !!(stbuf.st_size % (off_t) 512)) * 512;
+     if(flag & 32)
+       load_size= file_size * 512;
+   }
    if(platform_id == 0xef && (patch_isolinux & 0x3ff) == 0 &&
-      load_size == file_size && is_default_id && emul == 0) {
+      load_size / 512 == file_size && is_default_id && emul == 0) {
      sprintf(line, "-boot_image any efi_path=");
      Text_shellsafe(bin_path, line, 1);
      strcat(line, "\n");
@@ -466,9 +472,14 @@ int Xorriso_boot_item_status(struct XorrisO *xorriso, char *cat_path,
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2); 
  
- is_default= (load_size == 2048 || (flag & 4));
- sprintf(line, "-boot_image %s load_size=%lu\n",
-         form, (unsigned long) load_size);
+ if(flag & 32) {
+   is_default= 0;
+   sprintf(line, "-boot_image %s load_size=full", form);
+ } else {
+   is_default= (load_size == 2048 || (flag & 4));
+   sprintf(line, "-boot_image %s load_size=%lu\n",
+           form, (unsigned long) load_size);
+ }
  if(!(is_default && no_defaults))
    Xorriso_status_result(xorriso,filter,fp,flag&2); 
 
@@ -1169,7 +1180,7 @@ int Xorriso_mount(struct XorrisO *xorriso, char *dev, int adr_mode,
      if(WIFEXITED(status) && WEXITSTATUS(status) != 0) {
        sprintf(xorriso->info_text,
                "-mount : mount command failed with exit value %d",
-               (int) WEXITSTATUS(ret));
+               (int) WEXITSTATUS(status));
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
        ret= 0; goto ex;
      }
@@ -1636,8 +1647,10 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
  int cared_for_sparc= 0, have_hfsplus= 0;
  int have_sysarea= 0, ptable_killer, imported_iso, have_alpha_ldr_path= 0;
  int have_protective_msdos= 0, appended_partition= 0, part_like_isohybrid= 0;
+ int iso_mbr_part_type= -1;
+ unsigned int prev_pltf= 0;
  unsigned long int sa_options= 0, partno, id_tag, perms, start_cyl, num_blocks;
- unsigned long int part_status, part_type, start_block;
+ unsigned long int part_status, part_type, start_block, partition_offset= 0;
  uint32_t high_block= 0;
  char name[24], *textpt, *contentpt, *buf= NULL;
  char **lines= NULL;
@@ -1649,8 +1662,9 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
  struct FindjoB *job= NULL;
  struct stat dir_stbuf;
  IsoImage *image;
- char *volid, *crt, *mdt, *ext, *eft, uuid[17];
+ char *volid, *crt, *mdt, *ext, *eft, uuid[17], *uuid_time;
  char **app_pseudo_paths= NULL;
+ struct tm tm_erg;
 
  struct mbr_par {
    uint8_t ptype;
@@ -1735,6 +1749,10 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
    } else if(strcmp(name, "ISO image size/512 :") == 0) {
      img_blocks= num[0];
 
+   } else if(strcmp(name, "Partition offset   :") == 0 &&
+      (num[0] == 0 || num[0] == 16)) {
+     partition_offset= num[0];
+
    }
  }
 
@@ -1787,27 +1805,38 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
  Xorriso_record_cmd_linE
  ret= iso_image_get_pvd_times(image, &crt, &mdt, &ext, &eft);
  if(ret == ISO_SUCCESS) {
-   if(mkisofs)
-     sprintf(buf, "--modification-date=");
-   else
-     sprintf(buf, "-volume_date uuid ");
+   uuid_time= crt;
+   /* If Creation Time is bad and Modification Time is ok: use the latter */
+   ret= Decode_ecma119_format(&tm_erg, crt, 0);
+   if(ret <= 0 || strlen(crt) != 16) {
+     ret= Decode_ecma119_format(&tm_erg, mdt, 0);
+     if(!(ret <= 0 || strlen(mdt) != 16))
+       uuid_time= mdt;
+   }
    pad= 0;
    for(j= 0; j < 16; j++) {
      if(pad) {
        uuid[j]= '0';
-     } else if(crt[j] == 0) {
+     } else if(uuid_time[j] == 0) {
        pad= 1;
        uuid[j]= '0';
-     } else if(crt[j] < '0' || crt[j] > '9') {
+     } else if(uuid_time[j] < '0' || uuid_time[j] > '9') {
        uuid[j]= '0';
      } else {
-       uuid[j]= crt[j];
+       uuid[j]= uuid_time[j];
      }
    }
    uuid[16]= 0;
-   Text_shellsafe(uuid, buf, 1);
+   ret= Decode_ecma119_format(&tm_erg, uuid, 0);
+   if(!(ret <= 0 || strlen(uuid) != 16)) {
+     if(mkisofs)
+       sprintf(buf, "--modification-date=");
+     else
+       sprintf(buf, "-volume_date uuid ");
+     Text_shellsafe(uuid, buf, 1);
+     Xorriso_record_cmd_linE
+   }
  }
- Xorriso_record_cmd_linE
 
  /* First pass: set up objects, record El Torito and info needed in 2nd pass */
  for(i= 0; i < line_count; i++) {
@@ -1883,6 +1912,9 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
      mbrpts[idx].block_count= num_blocks;
      if(num_blocks > 0 && start_block + num_blocks > mbr_parts_end)
        mbr_parts_end= start_block + num_blocks; 
+     if(start_block == partition_offset * 4 &&
+        (start_block + num_blocks) >= high_block * 4 && iso_mbr_part_type < 0)
+       iso_mbr_part_type = part_type;
 
    } else if(strcmp(name, "MBR partition path :") == 0) {
      idx= num[0] - 1;
@@ -1901,7 +1933,7 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
 
    } else if(strcmp(name, "GPT start and size :") == 0) {
      idx= num[0] - 1;
-     if(img_blocks <= num[1] && num[2] > 0)
+     if(num[2] > 0)
        appended_as_gpt= 1;
      gpts[idx].start_block= num[1];
      gpts[idx].block_count= num[2];
@@ -2048,8 +2080,8 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
        Xorriso_add_intvl_adr(xorriso, buf, (uint64_t) start_block,
                              ((uint64_t) start_block) + num_blocks - 1, "d",
                              imported_iso);
-    } else if((part_status & 0x80) && part_type == 0x00 &&
-              start_block == 0 && num_blocks == 1) {
+     } else if((part_status & 0x80) && part_type == 0x00 &&
+               start_block == 0 && num_blocks == 1) {
        if(mkisofs)
          sprintf(buf, "--mbr-force-bootable");
        else
@@ -2129,29 +2161,39 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
 
      if(high_block < num[1] && num[2] > 0 && !gpts[idx].is_gap) {
        for(mbr_idx = 0; mbr_idx < mbr_count; mbr_idx++) {
-         if(mbrpts[mbr_idx].start_block == num[1] &&
-            mbrpts[mbr_idx].block_count == num[2])
+         if(mbrpts[mbr_idx].start_block == num[1]) {
+           if(mbrpts[mbr_idx].block_count != num[2] && !(flag & 1)) {
+             sprintf(xorriso->info_text,
+                     "GPT partition %d has same start block as MBR partition %d but different block count (%.f <> %.f)",
+                     idx + 1, mbr_idx + 1, num[2],
+                     (double) mbrpts[mbr_idx].block_count);
+             Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING",
+                                 0);
+           }
        break;
+         }
        }
        if(mbr_idx >= mbr_count) {
-         if(appended_as_gpt == 1) {
-           if(mkisofs)
-             sprintf(buf, "-appended_part_as_gpt");
-           else
-             sprintf(buf, "-boot_image any appended_part_as=gpt");
-           Xorriso_record_cmd_linE
+         if(appended_as_gpt == 1)
            appended_as_gpt= 2;
-         }
          sprintf(buf, "-append_partition %d 0x%lx ", idx + 1, part_type);
          Xorriso_add_intvl_adr(xorriso, buf, (uint64_t) num[1],
                                (uint64_t) (num[1] + num[2] - 1.0), "d",
                                imported_iso);
+         Xorriso_record_cmd_linE
+         buf[0]= 0;
          appended_partition= 1;
        }
 
-       ret= Xorriso_search_eltorito_lba(xorriso, et_imgs, elto_count,
-                                        (unsigned int) (num[1] / 4.0),
-                                        &et_idx, 0);
+       /* Check for isohybri-ish MBR and GPT mix */
+       if(mbr_count == 1 && mbrpts[0].ptype == 0xee && have_protective_msdos) {
+         /* real GPT is not -part_like_isohybrid */
+         ret= 0;
+       } else {
+         ret= Xorriso_search_eltorito_lba(xorriso, et_imgs, elto_count,
+                                          (unsigned int) (num[1] / 4.0),
+                                          &et_idx, 0);
+       }
        if(ret > 0) {
          if(!(et_imgs[et_idx].do_gpt_basdat ||
               et_imgs[et_idx].do_gpt_hfsplus ||
@@ -2163,6 +2205,7 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
            Xorriso_record_cmd_linE
            buf[0]= 0;
            part_like_isohybrid= 1;
+           appended_as_gpt= 0;
          }
          /*  mark el torito for  -isohybrid-gpt-... */
          Xorriso_register_eltorito_gpt(xorriso, et_imgs + et_idx,
@@ -2346,6 +2389,14 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
      Xorriso_record_cmd_linE
  }
 
+ if(appended_as_gpt == 2) {
+   if(mkisofs)
+     sprintf(buf, "-appended_part_as_gpt");
+   else
+     sprintf(buf, "-boot_image any appended_part_as=gpt");
+   Xorriso_record_cmd_linE
+ }
+
  if(have_sparc_part) {
    if(full_sparc_part == 255) {
      if(mkisofs) {
@@ -2385,6 +2436,15 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
    Xorriso_record_cmd_linE
    did_sysarea= 1;
  }
+ if(iso_mbr_part_type >= 0) {
+   if(mkisofs)
+     sprintf(buf, "-iso_mbr_part_type 0x%2.2x",
+                  (unsigned int) iso_mbr_part_type);
+   else
+     sprintf(buf, "-boot_image any iso_mbr_part_type=0x%2.2x",
+                  (unsigned int) iso_mbr_part_type);
+   Xorriso_record_cmd_linE
+ }
 
  /* Issue commands related to El Torito */
  if(elto_count <= 0)
@@ -2489,24 +2549,22 @@ static int Xorriso_scan_report_lines(struct XorrisO *xorriso,
  continue;
      }
    }
-   if(et_imgs[idx].platform_id == 0) {
-     if(mkisofs)
+   if(et_imgs[idx].platform_id != 0xef) {
+     if(mkisofs) {
+       if(prev_pltf != et_imgs[idx].platform_id) {
+         sprintf(buf, "-eltorito-platform 0x%2.2x", et_imgs[idx].platform_id);
+         Xorriso_record_cmd_linE
+       }
+       prev_pltf= et_imgs[idx].platform_id;
        sprintf(buf, "-b ");
-     else
+     } else {
        sprintf(buf, "-boot_image %s bin_path=", et_imgs[idx].boot_image_type);
-   } else if(et_imgs[idx].platform_id == 0xef) {
+     }
+   } else {
      if(mkisofs)
        sprintf(buf, "-e ");
      else
        sprintf(buf, "-boot_image %s efi_path=", et_imgs[idx].boot_image_type);
-   } else {
-     if(mkisofs && !(flag & 1)) {
-       sprintf(xorriso->info_text,
-               "Cannot enable EL Torito boot image #%d because Platform Id 0x%2.2x cannot be expressed in mkisofs emulation",
-               idx + 1, et_imgs[idx].platform_id);
-       Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
- continue;
-     }
    }
    Text_shellsafe(et_imgs[idx].path, buf, 1);
    Xorriso_record_cmd_linE
