@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2015 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2017 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -95,18 +95,37 @@ int Xorriso_option_acl(struct XorrisO *xorriso, char *mode, int flag)
 }
 
 
+/* @param flag bit3= unescape \\
+*/
+static void unescape_pathspec_part(char *rpt, int flag)
+{
+ char *wpt;
+
+ wpt= rpt;
+ for(; *rpt != 0; rpt++) {
+   if(*rpt == '\\') {
+     if(*(rpt + 1) == '=')
+ continue;
+     if((flag & 8) && *(rpt + 1) == '\\')
+       rpt++;
+   }
+   *(wpt++)= *rpt;
+ }
+ *wpt= 0;
+}
+
+
 /* Option -add */
 /* @param flag bit0=do not report the added item
                bit1=do not reset pacifier, no final pacifier message
                bit2= prepend ISO working directory in any case
-               bit3= unescape \\
 */
 int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag)
 {
- int i, end_idx, ret, was_failure= 0, fret, optc= 0, split;
+ int i, end_idx, ret, was_failure= 0, fret, optc= 0, split, as_mkisofs= 0;
  char *target= NULL, *source= NULL, *ept, *eff_path= NULL;
- char **optv= NULL, *rpt, *wpt;
+ char **optv= NULL;
 
  ret= Xorriso_opt_args(xorriso, "-add", argc, argv, *idx, &end_idx,
                        &optc, &optv, ((!!xorriso->allow_graft_points)<<2)|2);
@@ -117,6 +136,8 @@ int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
  Xorriso_alloc_meM(source, char, SfileadrL);
  Xorriso_alloc_meM(eff_path, char, SfileadrL);
 
+ if(xorriso->allow_graft_points & 2)
+   as_mkisofs= 8;
  if(!(flag&2))
    Xorriso_pacifier_reset(xorriso, 0);
  for(i= 0; i<optc; i++) {
@@ -125,27 +146,21 @@ int Xorriso_option_add(struct XorrisO *xorriso, int argc, char **argv,
    strcpy(source, optv[i]);
    split= 0;
    if(xorriso->allow_graft_points) {
-     ret= Fileliste__target_source_limit(target, '=', &ept, 0);
+     ret= Fileliste__target_source_limit(target, '=', &ept,
+                                         !(xorriso->allow_graft_points & 2));
      if(ret>0) {
        *ept= 0;
        strcpy(source, ept+1);
        split= 1;
      }
      /* unescape \= */;
-     if(split)
-       rpt= wpt= target;
-     else
-       rpt= wpt= source;
-     for(; *rpt!=0; rpt++) {
-       if(*rpt=='\\') {
-         if(*(rpt+1)=='=')
-     continue;
-         if((flag & 8) && *(rpt + 1) == '\\')
-           rpt++;
-       }
-       *(wpt++)= *rpt;
+     if(split) {
+       unescape_pathspec_part(target, as_mkisofs);
+       if(as_mkisofs)
+         unescape_pathspec_part(source, as_mkisofs);
+     } else {
+       unescape_pathspec_part(source, as_mkisofs);
      }
-     *wpt= 0;
    }
    if(split==0)
      strcpy(target, source);
@@ -798,6 +813,7 @@ treatment_patch:;
      strcat(xorriso->boot_image_bin_path, "isolinux.bin");
      strcat(xorriso->boot_image_cat_path, "boot.cat");
      xorriso->boot_image_load_size= 4 * 512;
+     xorriso->boot_img_size_default= 0;
      xorriso->keep_boot_image= 0;
      xorriso->patch_isolinux_image= (xorriso->patch_isolinux_image & ~3) | 1;
      strcpy(xorriso->boot_image_bin_form, formpt);
@@ -817,15 +833,21 @@ treatment_patch:;
    xorriso->boot_image_bin_path[0] = 0;
    xorriso->boot_efi_default= 0;
  } else if(strncmp(treatpt, "bin_path=", 9) == 0) {
-   ret= Xorriso_normalize_img_path(xorriso, xorriso->wdi, treatpt + 9,
-                                   xorriso->boot_image_bin_path, 2);
-   if(ret <= 0)
-     goto ex;
+   if(strncmp(treatpt + 9,  "--interval:appended_partition_", 30) == 0) {
+     strcpy(xorriso->boot_image_bin_path, treatpt + 9);
+   } else {
+     ret= Xorriso_normalize_img_path(xorriso, xorriso->wdi, treatpt + 9,
+                                     xorriso->boot_image_bin_path, 2);
+     if(ret <= 0)
+       goto ex;
+   }
    xorriso->keep_boot_image= 0;
    if(isolinux_grub) {
      xorriso->patch_isolinux_image= (xorriso->patch_isolinux_image & ~3) | 1;
-     if(xorriso->boot_image_bin_path[0])
+     if(xorriso->boot_image_bin_path[0]) {
        xorriso->boot_image_load_size= 4 * 512;
+       xorriso->boot_img_size_default= 0;
+     }
      strcpy(xorriso->boot_image_bin_form, formpt);
    } else
      strcpy(xorriso->boot_image_bin_form, "any");
@@ -835,10 +857,14 @@ treatment_patch:;
    xorriso->boot_image_bin_path[0] = 0;
    xorriso->boot_efi_default= 0;
  } else if(strncmp(treatpt, "efi_path=", 9) == 0) {
-   ret= Xorriso_normalize_img_path(xorriso, xorriso->wdi, treatpt + 9,
+   if(strncmp(treatpt + 9,  "--interval:appended_partition_", 30) == 0) {
+     strcpy(xorriso->boot_image_bin_path, treatpt + 9);
+   } else {
+     ret= Xorriso_normalize_img_path(xorriso, xorriso->wdi, treatpt + 9,
                                    xorriso->boot_image_bin_path, 2);
-   if(ret <= 0)
-     goto ex;
+     if(ret <= 0)
+       goto ex;
+   }
    xorriso->keep_boot_image= 0;
    xorriso->boot_efi_default= 1;
 
@@ -945,15 +971,20 @@ treatment_patch:;
      was_ok= 0;
 
  } else if(strncmp(treatpt, "load_size=", 10) == 0) {
-   num= Scanf_io_size(treatpt + 10, 0);
-   if(num < 512 && isolinux_grub) {
-     sprintf(xorriso->info_text,
-             "-boot_image %s : load_size too small (%s < 512)",
-             formpt, treatpt + 10);
-     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
-     {ret= 0; goto ex;}
+   if(strcmp(treatpt + 10, "full") == 0) {
+     xorriso->boot_img_full_size= 1;
+   } else {
+     num= Scanf_io_size(treatpt + 10, 0);
+     if(num < 512 && isolinux_grub) {
+       sprintf(xorriso->info_text,
+               "-boot_image %s : load_size too small (%s < 512)",
+               formpt, treatpt + 10);
+       Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+       {ret= 0; goto ex;}
+     }
+     xorriso->boot_image_load_size= num;
    }
-   xorriso->boot_image_load_size= num;
+   xorriso->boot_img_size_default= 0;
 
  } else if(strncmp(treatpt, "id_string=", 10) == 0) {
    memset(xorriso->boot_id_string, 0, 29);
@@ -991,6 +1022,8 @@ treatment_patch:;
    if(ret <= 0)
      goto ex;
    xorriso->system_area_options&= ~0x4000;
+   if(strcmp(treatpt + 12, "/dev/zero") == 0)
+     xorriso->system_area_clear_loaded= 1;
 
  } else if(strncmp(treatpt, "partition_table=", 16)==0) {
    if(strcmp(treatpt + 16, "off") == 0) {
@@ -1043,9 +1076,45 @@ treatment_patch:;
      xorriso->appended_as_gpt = 1;
    } else if(strcmp(treatpt + 17, "mbr") == 0) {
      xorriso->appended_as_gpt = 0;
+     xorriso->appended_as_apm = 0;
+   } else if(strcmp(treatpt + 17, "apm") == 0) {
+     xorriso->appended_as_apm = 1;
    } else
      was_ok= 0;
 
+ } else if(strncmp(treatpt, "gpt_disk_guid=", 14) == 0) {
+   ret= Xorriso_parse_gpt_guid(xorriso, treatpt + 14, 0);
+   if(ret <= 0)
+     goto ex;
+
+ } else if(strncmp(treatpt, "part_like_isohybrid=", 20) == 0) {
+   if(strcmp(treatpt + 20, "on") == 0)
+     xorriso->part_like_isohybrid= 1;
+   else if(strcmp(treatpt + 20, "off") == 0)
+     xorriso->part_like_isohybrid= 0;
+   else
+     was_ok= 0;
+
+ } else if(strncmp(treatpt, "iso_mbr_part_type=", 18) == 0) {
+   ret= 256;
+   if(strncmp(treatpt + 18, "default", 2) == 0) {
+     ret= -1;
+   } else if(strncmp(treatpt + 18, "0x", 2) == 0) {
+     u= 256;
+     sscanf(treatpt + 20, "%x", &u);
+     ret= u;
+   } else {
+     sscanf(treatpt + 18, "%d", &ret);
+   }
+   if(ret < -1 || ret > 0xff) {
+     sprintf(xorriso->info_text,
+     "-boot_image %s : iso_mbr_part_type='%s' wrong (\"default\", 0 ... 255, 0x00 ... 0xff)",
+             formpt, treatpt + 18);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+     {ret= 0; goto ex;}
+   }
+   xorriso->iso_mbr_part_type= ret;
+
  } else if(strncmp(treatpt, "partition_hd_cyl=", 17)==0) {
    u= 0;
    sscanf(treatpt + 17, "%u", &u);
@@ -1243,6 +1312,19 @@ treatment_patch:;
    else 
      xorriso->system_area_options|= 0x4000;
 
+ } else if(strncmp(treatpt, "mbr_force_bootable=", 19) == 0) {
+   if(strcmp(treatpt + 19, "off") == 0) {
+     xorriso->system_area_options&= ~(1 << 15);
+   } else if(strcmp(treatpt + 19, "on") == 0) {
+     xorriso->system_area_options|= (1 << 15);
+   } else {
+     sprintf(xorriso->info_text,
+             "-boot_image %s mbr_force_bootable=: unknown mode : %s",
+             formpt, treatpt + 19);
+     Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+     {ret= 0; goto ex;}
+   }
+
  } else
    was_ok= 0;
 
@@ -2044,7 +2126,7 @@ int Xorriso_option_close_filter_list(struct XorrisO *xorriso, int flag)
 
 /* Option -commit */
 /* @param flag bit0= leave indrive and outdrive acquired as they were,
-                     i.e. do not aquire outdrive as new in-out-drive
+                     i.e. do not acquire outdrive as new in-out-drive
                bit1= do not perform eventual -reassure
    @return <=0 error , 1 success, 2 revoked by -reassure , 3 no change pending
 */
