@@ -82,6 +82,7 @@ int Xorriso_end_idx(struct XorrisO *xorriso,
                bit7= silently tolerate empty argument list
                bit8= free the eventually allocated sub_vector
                bit9= always expand wildcards
+              bit10= do not add unresolved pattern to optv
 */
 int Xorriso_opt_args(struct XorrisO *xorriso, char *cmd,
                      int argc, char **argv, int idx,
@@ -116,10 +117,19 @@ int Xorriso_opt_args(struct XorrisO *xorriso, char *cmd,
    return(*end_idx);
  if((flag&16) && (*end_idx)>idx)
    (*end_idx)--;
+
  *optc= *end_idx - idx;
- *optv= argv+idx;
- if(*optc<=0 || !do_expand)
+ *optv= NULL;
+ if(*optc<=0 || !do_expand) {
+   if(*optc > 0) {
+     Xorriso_alloc_meM(*optv, char *,  *optc);
+     for(i= 0; i < *optc; i++) {
+       Xorriso_alloc_meM((*optv)[i], char, strlen(argv[idx + i]) + 1);
+       strcpy((*optv)[i], argv[idx + i]);
+     }
+   }
    return(1);
+ }
  patterns= calloc(*optc, sizeof(char *));
  if(patterns==NULL) {
 no_memory:;
@@ -147,10 +157,12 @@ no_memory:;
  }
  if(flag&2)
    ret= Xorriso_expand_disk_pattern(xorriso, nump, patterns, was_empty,
-                                    &filec, &filev, &mem, (flag>>5)&3);
+                                 &filec, &filev, &mem,
+                                 ((flag >> 5) & 3) | ((!!(flag & 1024)) << 3));
  else
    ret= Xorriso_expand_pattern(xorriso, nump, patterns, was_empty, 
-                               &filec, &filev, &mem, (flag>>5)&3);
+                               &filec, &filev, &mem,
+                               ((flag >> 5) & 3) | ((!!(flag & 1024)) << 3));
  if(ret<=0)
    {ret= 0; goto ex;}
  for(i= 0; i<was_empty; i++) {
@@ -545,7 +557,8 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "session_log","sh_style_result","signal_handling","sleep",
     "speed","split_size","status","status_history_max",
     "stdio_sync","stream_recording","system_id","temp_mem_limit","toc_of",
-    "uid","unregister_filter","use_readline","volid","volset_id",
+    "uid","unregister_filter","use_immed_bit","use_readline",
+    "volid","volset_id",
     "write_type","xattr","zisofs",
     ""
  };
@@ -579,7 +592,8 @@ int Xorriso_count_args(struct XorrisO *xorriso, int argc, char **argv,
     "getfattr","getfattri","getfattr_r","getfattr_ri","hide",
     "launch_frontend","ls","lsi","lsl","lsli","lsd","lsdi","lsdl","lsdli",
     "lsx","lslx","lsdx","lsdlx","map_l","mv","mvi","mkdir","mkdiri",
-    "not_paths","rm","rmi","rm_r","rm_ri","rmdir","rmdiri","update_l",
+    "not_paths","rm","rmi","rm_r","rm_ri","rmdir","rmdiri",
+    "update_l","update_li","update_lx","update_lxi",
     "setfacl","setfacli","setfacl_list","setfacl_listi",
     "setfacl_r","setfacl_ri","setfattr","setfattri",
     "setfattr_list","setfattr_listi","setfattr_r","setfattr_ri",
@@ -685,7 +699,7 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "* Character sets:",
    "charset", "local_charset",
 
-   "* Aquiring source and target drive:",
+   "* Acquiring source and target drive:",
    "dev", "indev", "outdev",
 
    "* Drive and media related inquiry actions (2):",
@@ -703,7 +717,8 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "* Inserting files into ISO image:",
    "disk_pattern", "add_plainly",
    "mkdir", "lns", "add", "path_list", "quoted_path_list",
-   "map", "map_single", "map_l", "update", "update_r", "update_l",
+   "map", "map_single", "map_l", "update", "update_r",
+   "update_l", "update_li", "update_lx", "update_lxi",
    "cut_out", "cpr", 
    "clone", "cp_clone",
 
@@ -739,7 +754,7 @@ int Xorriso_cmd_sorting_rank(struct XorrisO *xorriso,
    "abstract_file", "biblio_file", "preparer_id", "application_use",
    "out_charset", "read_mkisofsrc",
    "uid", "gid", "zisofs", "speed", "stream_recording", "dvd_obs",
-   "modesty_on_drive",
+   "modesty_on_drive", "use_immed_bit",
    "stdio_sync", "dummy", "fs", "close", "padding", "write_type",
    "grow_blindly", "pacifier", "scdbackup_tag",
 
@@ -923,7 +938,7 @@ ex:
                bit1= these are command line arguments
                      (for xorriso->argument_emulation)
                bit2= Only execute the one command argv[*idx] and advance 
-                     *idx to the next command if sucessful. Then return.
+                     *idx to the next command if successful. Then return.
 */
 int Xorriso_interpreter(struct XorrisO *xorriso,
                         int argc, char **argv, int *idx, int flag)
@@ -1926,13 +1941,23 @@ if (0) {
    (*idx)+= 2;
    ret= Xorriso_option_update(xorriso, arg1, arg2, 1);
 
- } else if(strcmp(cmd,"update_l")==0) {
+ } else if(strcmp(cmd,"update_l") == 0 || strcmp(cmd,"update_lx") == 0) {
    ret= Xorriso_option_map_l(xorriso, argc, argv, idx, 2<<8);
 
+ } else if(strcmp(cmd,"update_li") == 0) {
+   ret= Xorriso_option_map_l(xorriso, argc, argv, idx, 5 << 8);
+
+ } else if(strcmp(cmd,"update_lxi") == 0) {
+   ret= Xorriso_option_map_l(xorriso, argc, argv, idx, 4 << 8);
+
  } else if(strcmp(cmd,"update_r")==0) {
    (*idx)+= 2;
    ret= Xorriso_option_update(xorriso, arg1, arg2, 1|8);
 
+ } else if(strcmp(cmd,"use_immed_bit")==0) {
+   (*idx)++;
+   ret= Xorriso_option_use_immed_bit(xorriso, arg1, 0);
+
  } else if(strcmp(cmd,"use_readline")==0) {
    (*idx)++;
    ret= Xorriso_option_use_readline(xorriso, arg1, 0);
@@ -2544,10 +2569,70 @@ ex:;
 }
 
 
+/* https://reproducible-builds.org/specs/source-date-epoch/
+   and reproducible-builds@lists.alioth.debian.org in august 2016
+*/
+int Xorriso_source_date_epoch(struct XorrisO *xorriso, int flag)
+{
+ char *sec_text, double_text[40];
+ double dsec= -1.0;
+ time_t tsec;
+ struct tm *gmt;
+
+ sec_text= getenv("SOURCE_DATE_EPOCH");
+ if(sec_text == NULL)
+   return(2);
+
+ sscanf(sec_text, "%lf", &dsec);
+ sprintf(double_text, "%.f", dsec);
+ tsec= dsec;
+ if(dsec < 0 || ((double) tsec) != dsec ||
+    strcmp(sec_text, double_text) != 0) {
+malformed:;
+   Xorriso_msgs_submit(xorriso, 0,
+                "Malformed environment variable SOURCE_DATE_EPOCH encountered",
+                       0, "SORRY", 0);
+   Xorriso_msgs_submit(xorriso, 0,
+                "Unset SOURCE_DATE_EPOCH before starting xorriso or see https://reproducible-builds.org/specs/source-date-epoch/",
+                       0, "HINT", 0);
+   return(0);
+ }
+ gmt= gmtime(&tsec);
+ if(gmt == NULL)
+   goto malformed;
+ sprintf(xorriso->vol_uuid, "%4.4d%2.2d%2.2d%2.2d%2.2d%2.2d00",
+         1900 + gmt->tm_year, gmt->tm_mon + 1, gmt->tm_mday,
+         gmt->tm_hour, gmt->tm_min, gmt->tm_sec);
+ xorriso->gpt_guid_mode= 2; /* Disk GUID from vol_uuid */
+ strcpy(xorriso->all_file_dates, "set_to_mtime");
+ sprintf(xorriso->info_text,
+         "Environment variable SOURCE_DATE_EPOCH encountered with value %s",
+         sec_text);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "NOTE", 0);
+ sprintf(xorriso->info_text, "SOURCE_DATE_EPOCH : -volume_date uuid %s",
+                             xorriso->vol_uuid);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ sprintf(xorriso->info_text,
+                          "SOURCE_DATE_EPOCH : -volume_date all_file_dates %s",
+                          xorriso->all_file_dates);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ sprintf(xorriso->info_text,
+                       "SOURCE_DATE_EPOCH : -boot_image any volume_date_uuid");
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ return(1);
+}
+
+
 int Xorriso_read_rc(struct XorrisO *xorriso, int flag)
 {
  int ret,i,was_failure= 0,fret;
 
+ /* Interpret environment variable SOURCE_DATE_EPOCH */
+ ret= Xorriso_source_date_epoch(xorriso, 0);
+ ret= Xorriso_eval_problem_status(xorriso, ret, 0);
+ if(ret < 0)
+   return(0);
+
  if(xorriso->no_rc)
    return(1);
  i= xorriso->rc_filename_count-1;
