@@ -2,7 +2,7 @@
 /* xorriso - Command line oriented batch and dialog tool which creates, loads,
    manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2016 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2017 Thomas Schmitt, <scdbackup@gmx.net>
 
    Initial code of this program was derived from program src/askme.c out
    of scdbackup-0.8.8, Copyright 2007 Thomas Schmitt, BSD-License.
@@ -77,10 +77,10 @@
    disk_ops.c       actions on onjects of disk filesystems
    cmp_update.c     compare or update files between disk filesystem and
                     ISO filesystem
-   opts_a_c.c       options -a* to -c*
-   opts_d_h.c       options -d* to -h*
-   opts_i_o.c       options -i* to -o*
-   opts_p_z.c       options -p* to -z*
+   opts_a_c.c       commands -a* to -c*
+   opts_d_h.c       commands -d* to -h*
+   opts_i_o.c       commands -i* to -o*
+   opts_p_z.c       commands -p* to -z*
 
    xorriso_private.h contains the definition of struct Xorriso and for
    convenience includes the .h files of the non-library group.
@@ -111,7 +111,7 @@
 */
 #define Xorriso_req_majoR  1
 #define Xorriso_req_minoR  4
-#define Xorriso_req_micrO  6
+#define Xorriso_req_micrO  8
 
 
 static void yell_xorriso()
@@ -213,8 +213,8 @@ int main(int argc, char **argv)
 
  if(argc < 2) {
    yell_xorriso();
-   fprintf(stderr,"usage : %s [options]\n", argv[0]);
-   fprintf(stderr, "        More is told by option -help\n");
+   fprintf(stderr,"usage : %s [commands]\n", argv[0]);
+   fprintf(stderr, "        More is told by command -help\n");
    exit(2);
  }
  setlocale(LC_CTYPE, "");
